use clap::Parser;

static mut ROOT_CERT: Option<Vec<u8>> = None;

/// TCP relay client
#[derive(Parser, Debug, Clone)]
#[clap(author, version, about, long_about = None)]
pub struct ClientConfig {
    /// Access token
    #[clap(short, long)]
    pub token: String,

    /// Relay server
    #[clap(short, long, default_value = "http://127.0.0.1:8000")]
    pub relay_url: String,

    /// Listen address
    #[clap(short, long, default_value = "127.0.0.1")]
    pub listen_address: String,

    /// Optional root certificate to use for server authentication
    #[clap(short = 'c', long)]
    pub root_certificate: Option<String>,
}

impl ClientConfig {
    /// Load root certificate
    pub fn get_root_certificate(&self) -> Option<Vec<u8>> {
        self.root_certificate.as_ref()?;

        if unsafe { ROOT_CERT.is_none() } {
            log::info!("Loading root certificate from disk");
            let cert = self.root_certificate.as_ref().map(|c| std::fs::read(c)
                .expect("Failed to read root certificate!"));
            unsafe { ROOT_CERT = cert }
        }

        unsafe { ROOT_CERT.clone() }
    }
}